@@ -1,20 +1,23 @@
+
 from AccessControl import ClassSecurityInfo
 from Acquisition.interfaces import IAcquirer
+from Acquisition import aq_parent
 from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
 from Persistence import Persistent
 from Products.PageTemplates.Expressions import SecureModuleImporter
-from Shared.DC.Scripts.Bindings import Bindings
 import Acquisition
 import OFS
 
 import zope.cachedescriptors.property
+from zope.interface import implements
 from zope.i18nmessageid import MessageFactory
 
+from Products.Formulator.interfaces import IField
 from Products.Formulator.Errors import ValidationError
 from Products.Formulator.Widget import MultiItemsWidget
 from Products.Formulator.helpers import (
-    is_sequence, convert_unicode, key_to_id_re, id_value_re)
+    convert_unicode, key_to_id_re, id_value_re)
 
 
 class Field:
@@ -22,6 +25,7 @@ class Field:
     A field is an object consisting of a widget and a validator.
     """
     security = ClassSecurityInfo()
+    implements(IField)
 
     # this is a field
     is_field = 1
@@ -109,22 +113,20 @@ class Field:
         tales_expr = self.tales.get(id, "")
 
         if tales_expr:
-            # In old Zope version, for some reason, path expressions
-            # expect 'here' and 'request' to exist, otherwise they
-            # seem to fail. python expressions don't seem to have this
-            # problem. However on newer version, it's fixed, and you
-            # might not have request available as self.REQUEST (if
-            # your field is in a Zope utility).
+            # kw are the expression namespace. Fill in it correctly.
 
-            # add 'here' if not in kw
-            if not kw.has_key('here'):
-                kw['here'] = self.aq_parent
-            if hasattr(self, 'REQUEST'):
+            form = aq_parent(self)
+            context = aq_parent(form)
+            if 'here' not in kw:
+                kw['here'] = form
+            if 'request' not in kw and hasattr(self, 'REQUEST'):
                 kw['request'] = self.REQUEST
             kw['modules'] = SecureModuleImporter
             value = tales_expr.__of__(self)(
                 field=self,
-                form=self.aq_parent, **kw)
+                form=form,
+                context=context,
+                **kw)
         else:
             override = self.overrides.get(id, "")
             if override:
@@ -482,23 +484,6 @@ class ZMIField(
             if hasattr(self, method_name):
                 getattr(self, method_name)(values[key])
 
-
-##     security.declareProtected('Change Formulator Forms', 'manage_beforeDelete')
-##     def manage_beforeDelete(self, item, container):
-##         """Remove name from list if object is deleted.
-##         """
-##         # update group info in form
-##         if hasattr(item.aq_explicit, 'is_field'):
-##             container.field_removed(item.id)
-
-##     security.declareProtected('Change Formulator Forms', 'manage_afterAdd')
-##     def manage_afterAdd(self, item, container):
-##         """What happens when we add a field.
-##         """
-##         # update group info in form
-##         if hasattr(item.aq_explicit, 'is_field'):
-##             container.field_added(item.id)
-
     # methods screen
     security.declareProtected('View management screens',
                               'manage_overrideForm')
