@@ -1,8 +1,9 @@
-import string, types
-from DummyField import fields
-from DocumentTemplate.DT_Util import html_quote
+import string
+
 from DateTime import DateTime
-from helpers import is_sequence, id_value_re
+from DocumentTemplate.DT_Util import html_quote
+from Products.Formulator.DummyField import fields
+from Products.Formulator.helpers import is_sequence, id_value_re
 
 
 class Widget:
@@ -69,7 +70,7 @@ class Widget:
         "to add an onClick attribute to use with JavaScript, for instance."),
                                default="",
                                required=0)
- 
+
     #this property is used to determine whether the widget
     # uses an html id (e.g. the widget has a single or primary
     # input), so that the presentation can wrap the field
@@ -141,9 +142,10 @@ class TextWidget(Widget):
         """Render text input field.
         """
         extra = field.get_value('extra')
+        css_class = field.get_value('css_class')
         kw = {'type': "text",
                 'name' : key,
-                'css_class' : field.get_value('css_class'),
+                'css_class' : css_class,
                 'value' : value,
                 'size' : field.get_value('display_width'),
                 'extra': extra}
@@ -152,7 +154,8 @@ class TextWidget(Widget):
         display_maxwidth = field.get_value('display_maxwidth') or 0
         if display_maxwidth > 0:
             kw['maxlength'] = display_maxwidth
-        return render_element("input", **kw)
+        contents = render_element("input", **kw)
+        return render_element("div", contents=contents, css_class=css_class)
 
     def render_view(self, field, value):
         if value is None:
@@ -167,20 +170,22 @@ class PasswordWidget(TextWidget):
         """Render password input field.
         """
         extra = field.get_value('extra')
+        css_class = field.get_value('css_class')
         kw = {'type': "password",
               'name': key,
-              'css_class': field.get_value('css_class'),
+              'css_class': css_class,
               'value': value,
               'size': field.get_value('display_width'),
               'extra': extra}
-    
-        if not extra or not id_vlaue_re.search(extra):
+
+        if not extra or not id_value_re.search(extra):
             kw['id'] = field.generate_field_html_id(key)
 
         display_maxwidth = field.get_value('display_maxwidth') or 0
         if display_maxwidth > 0:
             kw['maxlength'] = display_maxwidth
-        return render_element("input", **kw)
+        contents = render_element("input", **kw)
+        return render_element("div", contents=contents, css_class=css_class)
 
     def render_view(self, field, value):
         return "[password]"
@@ -210,8 +215,7 @@ class CheckBoxWidget(Widget):
             kw['id'] = field.generate_field_html_id(key)
         if value:
             kw['checked']=None
-        contents = render_element("input", **kw)
-        return render_element('label', contents=contents)
+        return render_element("input", **kw)
 
     def render_view(self, field, value):
         if value:
@@ -253,14 +257,16 @@ class TextAreaWidget(Widget):
         width = field.get_value('width')
         height = field.get_value('height')
         extra=field.get_value('extra')
+        css_class = field.get_value('css_class')
         kw = {'name': key,
-              'css_class': field.get_value('css_class'),
+              'css_class': css_class,
               'cols': width,
               'rows': height,
               'contents': html_quote(value)}
         if not extra or not id_value_re.search(extra):
             kw['id'] = field.generate_field_html_id(key)
-        return render_element("textarea", **kw)
+        contents = render_element("textarea", **kw)
+        return render_element("div", contents=contents, css_class=css_class)
 
     def render_view(self, field, value):
         if value is None:
@@ -414,7 +420,7 @@ class SingleItemsWidget(ItemsWidget):
         field_html_id = None
         if not extra_item or not id_value_re.search(extra_item):
             field_html_id = field.generate_field_html_id(key)
-        
+
         # if we run into multiple items with same value, we select the
         # first one only (for now, may be able to fix this better later)
         selected_found = 0
@@ -579,7 +585,7 @@ class ListWidget(SingleItemsWidget):
     def render(self, field, key, value, REQUEST):
         rendered_items = self.render_items(field, key, value, REQUEST)
 
-        extra=field.get_value('extra')  
+        extra=field.get_value('extra')
         kw = {'name': key,
               'css_class': field.get_value('css_class'),
               'size': field.get_value('size'),
@@ -654,7 +660,7 @@ class RadioWidget(SingleItemsWidget):
                                    size=1,
                                    items=[('Vertical', 'vertical'),
                                           ('Horizontal', 'horizontal')])
-    
+
     has_html_id = False
 
     def render(self, field, key, value, REQUEST):
@@ -846,7 +852,7 @@ class DateTimeWidget(Widget):
                                       size=1)
 
     has_html_id = False
-    
+
     # FIXME: do we want to handle 'extra'?
 
     def render(self, field, key, value, REQUEST):
@@ -861,7 +867,7 @@ class DateTimeWidget(Widget):
 
         if value is None and field.get_value('default_now'):
             value = DateTime()
-            
+
         # Allow subfields to get their values even when default_now is set.
         if REQUEST is not None and \
                    REQUEST.form.has_key(field.generate_subfield_key('year')):
@@ -875,6 +881,8 @@ class DateTimeWidget(Widget):
             minute = None
             ampm = None
         else:
+            if not isinstance(value, DateTime):
+                value = DateTime(value)
             year = "%04d" % value.year()
             month = "%02d" % value.month()
             day = "%02d" % value.day()
@@ -904,11 +912,11 @@ class DateTimeWidget(Widget):
             if hide_day and (sub_field_name == 'day'):
                 dayvalue = sub_field_value
                 if dayvalue is None:
-                    dayvalue = "01" 
+                    dayvalue = "01"
                 sub_key = field.generate_subfield_key(sub_field_name)
                 sub_field = field.sub_form.get_field(sub_field_name)
                 hidden_day_part = sub_field.widget.\
-                                  render_hidden(sub_field, sub_key,    
+                                  render_hidden(sub_field, sub_key,
                                                 dayvalue, REQUEST)
             else:
                 result.append(field.render_sub_field(sub_field_name,
@@ -981,6 +989,8 @@ setTimeout(function(){Calendar.setup({inputField : '%s_hiddeninput',
         sub_values = {}
         subfields = ['year','month','day']
         if value is not None:
+            if not isinstance(value, DateTime):
+                value = DateTime(value)
             sub_values['year']  = '%04d' % value.year()
             sub_values['month'] = "%02d" % value.month()
             sub_values['day']   = "%02d" % value.day()
@@ -1010,6 +1020,8 @@ setTimeout(function(){Calendar.setup({inputField : '%s_hiddeninput',
 
         use_ampm = field.get_value('ampm_time_style')
 
+        if not isinstance(value, DateTime):
+            value = DateTime(value)
         year = "%04d" % value.year()
         month = "%02d" % value.month()
         day = "%02d" % value.day()
